# ////////// Contribution needed ///////////////////

BengaliProfanity = [
    "bokachoda", "abal", "gand", "gudmarani", "khankirchele", "machuda", "bonchod",
    "harami", "pagolchoda", "hol", "besya", "bal", "mang", "chudirbhai"
]